#include <node.h>
#include <node_buffer.h>
#include <iostream>
#include <typeinfo>

#ifdef __APPLE__
    #include "./kido-lib/platform/mac/mouse.cpp"
#elif WIN32
    #include "./kido-lib/platform/win32/mouse.cpp"
#elif __GNUC__
    #include "./kido-lib/platform/linux/mouse.cpp"
#else
    #define UNSUPPORTED_PLATFORM 1
#endif

namespace kido_node {

  using v8::FunctionCallbackInfo;
  using v8::Isolate;
  using v8::Local;
  using v8::Object;
  using v8::String;
  using v8::Value;

  using v8::Exception;

  void SetMousePosition (const FunctionCallbackInfo<Value>& args) {
    #ifdef UNSUPPORTED_PLATFORM
      isolate->ThrowException(Exception::TypeError(String::NewFromUtf8(isolate, "Unsupported Platform")));
    #endif

    Isolate* isolate = args.GetIsolate();
    
    // Check the argument types
    if (!args[0]->IsNumber() || !args[1]->IsNumber()) {
      isolate->ThrowException(Exception::TypeError(String::NewFromUtf8(isolate, "Wrong arguments")));
      return;
    }

    int x, y;

    x = args[0]->NumberValue();
    y = args[1]->NumberValue();

    IMouse * mouse = new Mouse();
    mouse->setPosition(x, y);
  }

  void init (Local<Object> exports) {
    NODE_SET_METHOD(exports, "setMousePosition", SetMousePosition);
  }

  NODE_MODULE(addon, init)
}
